//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Support/Data/Dirs.cpp
//! @brief     Implements class Dirs.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Support/Data/Dirs.h"
#include <QDir>
#include <QSettings>

namespace {

const QString S_DIRS = "Dirs";
const QString S_DEFAULTPROJECTPATH = "DefaultProjectPath";
const QString S_ARTIFACTEXPORTDIR = "ArtifactExportDir";
const QString S_DATAIMPORTDIR = "DataImportDir";
const QString S_SCRIPTIMPORTDIR = "ScriptImportDir";
const QString S_LASTUSEDIMPORFILTER1D = "LastUsedImportFilter1D";
const QString S_LASTUSEDIMPORFILTER2D = "LastUsedImportFilter2D";

} // namespace

BA_GUI_API_ std::unique_ptr<Dirs> gDirs;

Dirs::Dirs()
{
    artifact_export_dir = QDir::homePath();
    data_import_dir = QDir::homePath();
    script_import_dir = QDir::homePath();
    readSettings();
}

Dirs::~Dirs() = default;

//! Reads settings of Dirs from global settings.

void Dirs::readSettings()
{
    QSettings s;
    if (s.childGroups().contains(S_DIRS)) {
        s.beginGroup(S_DIRS);

        artifact_export_dir = s.value(S_ARTIFACTEXPORTDIR, artifact_export_dir).toString();
        data_import_dir = s.value(S_DATAIMPORTDIR, data_import_dir).toString();
        script_import_dir = s.value(S_SCRIPTIMPORTDIR, script_import_dir).toString();

        import_filter_1D = s.value(S_LASTUSEDIMPORFILTER1D, "").toString();
        import_filter_2D = s.value(S_LASTUSEDIMPORFILTER2D, "").toString();

        s.endGroup();
    }
}

//! Saves settings of Dirs in global settings.

void Dirs::writeSettings()
{
    QSettings s;
    s.beginGroup(S_DIRS);
    s.setValue(S_ARTIFACTEXPORTDIR, artifact_export_dir);
    s.setValue(S_DATAIMPORTDIR, data_import_dir);
    s.setValue(S_SCRIPTIMPORTDIR, script_import_dir);
    s.setValue(S_LASTUSEDIMPORFILTER1D, import_filter_1D);
    s.setValue(S_LASTUSEDIMPORFILTER2D, import_filter_2D);
    s.endGroup();
}
